self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "511554d099d9dcbafaa33b75cba75920",
    "url": "/v1/admin/index.html"
  },
  {
    "revision": "1f967a564e31facd01ef",
    "url": "/v1/admin/static/css/2.439435b7.chunk.css"
  },
  {
    "revision": "1f967a564e31facd01ef",
    "url": "/v1/admin/static/js/2.27efff26.chunk.js"
  },
  {
    "revision": "16d83d743e2df69a6240e859a1dd38b1",
    "url": "/v1/admin/static/js/2.27efff26.chunk.js.LICENSE.txt"
  },
  {
    "revision": "8655c02ee66f33a47766",
    "url": "/v1/admin/static/js/main.a9e9ceee.chunk.js"
  },
  {
    "revision": "9ef0d6507b831d1cab94",
    "url": "/v1/admin/static/js/runtime-main.6c5c2596.js"
  },
  {
    "revision": "7b1b3b1f9d0d7596ac24b9e087286b4b",
    "url": "/v1/admin/static/media/arrow-repeat.7b1b3b1f.svg"
  },
  {
    "revision": "fc1461bf3d517f652b0678d827f4cb7c",
    "url": "/v1/admin/static/media/box-arrow-right.fc1461bf.svg"
  },
  {
    "revision": "1a502d47858ccd206c29dfcd4906d228",
    "url": "/v1/admin/static/media/chat-left.1a502d47.svg"
  },
  {
    "revision": "bf9657ab7f0b4ed0a47f72a95c61dd34",
    "url": "/v1/admin/static/media/check.bf9657ab.svg"
  },
  {
    "revision": "70d04b1523d6cae0698836d3484db8d0",
    "url": "/v1/admin/static/media/check2.70d04b15.svg"
  },
  {
    "revision": "1f74995f1767c7a199149110131aed2e",
    "url": "/v1/admin/static/media/clipboard.1f74995f.svg"
  },
  {
    "revision": "aff79e60a889005ee8d5838a29329f60",
    "url": "/v1/admin/static/media/clock-history.aff79e60.svg"
  },
  {
    "revision": "7f9b096de45a15bbd3a9e0173de0deb4",
    "url": "/v1/admin/static/media/exclamation-circle-fill.7f9b096d.svg"
  },
  {
    "revision": "e8c7ae6e0daf6dd9aea423d23c370c53",
    "url": "/v1/admin/static/media/exclamation-triangle-fill.e8c7ae6e.svg"
  },
  {
    "revision": "ed90928cf711bdde2fb75cca170cdfb4",
    "url": "/v1/admin/static/media/eye-slash.ed90928c.svg"
  },
  {
    "revision": "25755a4d2f1f2b17006b986f8fc4c283",
    "url": "/v1/admin/static/media/eye.25755a4d.svg"
  },
  {
    "revision": "892c1fa2a790d1b2f029add4b1872c11",
    "url": "/v1/admin/static/media/folder2-open.892c1fa2.svg"
  },
  {
    "revision": "71993cca988891f2e4bd0b65855c4863",
    "url": "/v1/admin/static/media/folder2.71993cca.svg"
  },
  {
    "revision": "0444aa22285035a7ff1d8a75045c4420",
    "url": "/v1/admin/static/media/gear.0444aa22.svg"
  },
  {
    "revision": "cb248b18144bc603c7c65f99c8bf82d9",
    "url": "/v1/admin/static/media/info-circle-fill.cb248b18.svg"
  },
  {
    "revision": "6fcbc3fe95eedbfeeaba979e90bc744a",
    "url": "/v1/admin/static/media/justify.6fcbc3fe.svg"
  },
  {
    "revision": "8c3ea8bef03c75f94048a8fc19537d8f",
    "url": "/v1/admin/static/media/lock.8c3ea8be.svg"
  },
  {
    "revision": "5955773e1f31b849ffd918db16186cc3",
    "url": "/v1/admin/static/media/paperclip.5955773e.svg"
  },
  {
    "revision": "9af315a4756134eaf0224592c7458664",
    "url": "/v1/admin/static/media/pencil.9af315a4.svg"
  },
  {
    "revision": "bd3f8b819d9e93ca9fda18991d87f1ce",
    "url": "/v1/admin/static/media/person-fill.bd3f8b81.svg"
  },
  {
    "revision": "e8b9f90c67515282b6c0339c7b755374",
    "url": "/v1/admin/static/media/plus.e8b9f90c.svg"
  },
  {
    "revision": "96cbd40b39b9d5bac5a3ec65c4a8aaa4",
    "url": "/v1/admin/static/media/question-circle-fill.96cbd40b.svg"
  },
  {
    "revision": "5d6d3cf7b52907d3d0de3b3c6e21e8ad",
    "url": "/v1/admin/static/media/skip-start.5d6d3cf7.svg"
  },
  {
    "revision": "a88d29fdf97fdb41cef802b1a74dc1c6",
    "url": "/v1/admin/static/media/sort-down.a88d29fd.svg"
  },
  {
    "revision": "a6d6c664c963be71dc425d6766139c9e",
    "url": "/v1/admin/static/media/sort-up.a6d6c664.svg"
  },
  {
    "revision": "b39b3e89c405e669d18312fa306b96df",
    "url": "/v1/admin/static/media/three-dots.b39b3e89.svg"
  },
  {
    "revision": "d48003a0dfa1e753e0f694c5519c92c5",
    "url": "/v1/admin/static/media/trash.d48003a0.svg"
  },
  {
    "revision": "ab3d51bf61cd0a70817970f01040c051",
    "url": "/v1/admin/static/media/x-circle-fill.ab3d51bf.svg"
  }
]);